# Core package for any UNV-based application (United Vision)

[![Build Status](https://readthedocs.org/projects/unv_app/badge/?version=latest&style=flat)](https://readthedocs.org/projects/unv_app)
[![Docs Build Status](https://travis-ci.org/c137digital/unv_app.svg?branch=master)](https://travis-ci.org/c137digital/unv_app)
[![Maintainability](https://api.codeclimate.com/v1/badges/68b47ceb384c9b705a5b/maintainability)](https://codeclimate.com/github/c137digital/unv_app/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/68b47ceb384c9b705a5b/test_coverage)](https://codeclimate.com/github/c137digital/unv_app/test_coverage)
[![Requirements Status](https://requires.io/github/c137digital/unv_app/requirements.svg?branch=master)](https://requires.io/github/c137digital/unv_app/requirements/?branch=master)
[![PyPI implementation](https://img.shields.io/pypi/implementation/unv_app.svg)](https://pypi.python.org/pypi/unv_app/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/unv_app.svg)](https://pypi.python.org/pypi/unv_app/)
[![PyPI license](https://img.shields.io/pypi/l/unv_app.svg)](https://pypi.python.org/pypi/unv_app/)
[![PyPI version fury.io](https://badge.fury.io/py/unv.app.svg)](https://pypi.python.org/pypi/unv_app/)
[![PyPI download month](https://img.shields.io/pypi/dm/unv_app.svg)](https://pypi.python.org/pypi/unv_app/)

Core package for all sub-applications. Includes settings and component management.
